/*
	`xsvif.c'
	XSV Board loader interface routines

	20000516, Andrew Bardsley
*/

#ifndef XSVIF_HEADER
#define XSVIF_HEADER

#include <termios.h>
/* XSV_PACKSIZE: size of data payload of XSV_PACKPROG command */
#define XSV_PACKSIZE (1024)

/* XSV_Command: valid command characters to send to the loader */
typedef enum {
	XSV_NOP = '@',			/* do nothing, don't ack */
	XSV_ECHO = 'A',			/* just ack */
	XSV_BBBB = 'B',			/* FIXME */
	XSV_REPROG = 'C',		/* pulse /PROG on Virtex low, wait for INIT high, ack */
	XSV_PACKPROG = 'D',		/* packet programming, send XSV_PACKSIZE bytes to Virtex, ack */
	XSV_VIRSTX = 'E'
} XSV_Command;

/* XSV_CheckSum: current board checksum value */
extern unsigned char XSV_CheckSum;

/* XSV_OriginalPortSetttings: pre-XSV_OpenSerialPort serial
	port settings. */
extern struct termios XSV_OriginalPortSettings;

/* XSV_SerialPortFD: fildes for open serial port */
extern int XSV_SerialPortFD;

/* XSV_Cleanup: set this in your application to a function which
	cleans up the serial line/closes down app.  Called by XSV_Error
	before program exit */
extern void (* XSV_Cleanup) (void);

/* XSV_DefaultCleanup: default cleanup function set by XSV_Startup */
extern void  XSV_DefaultCleanup (void);

/* XSV_Error: simple fatal error report */
extern void XSV_Error (char *str);

/* XSV_OpenSerialPort: open the named serial port and return an
	open bidirectional file descriptor for raw I/O on that port.
	Sets up the port for: 115200 bps, 8 bits, no parity, 1 stop */
extern int XSV_OpenSerialPort (char *port);

/* XSV_Startup: run OpenSerialPort, setup cleanup function and signal handling */
extern void XSV_Startup (char *port);

/* XSV_CloseSerialPort: close the port opened on fildes `portFD'
	and restore the serial port's attributes */
extern void XSV_CloseSerialPort (int portFD);

/* XSV_PutData: write some data to the board, handle errors */
extern void XSV_PutData (int portFD, char *buffer, int bufferSize);

/* XSV_GetAck: get acknowledgement from board, handle timeout */
extern char XSV_GetAck (int portFD);

/* XSV_ProgramVirtex: program the Virtex device from the .bit
	file `filename'.  NB. doesn't frob /PROG first */
extern void XSV_DownloadBitFile (int portFD, char *filename);

#endif
